<?php

// +----------------------------------------------------------------------+
// | OpenConf                                                             |
// +----------------------------------------------------------------------+
// | Copyright (c) 2002-2009 Zakon Group LLC.  All Rights Reserved.       |
// +----------------------------------------------------------------------+
// | This source file is subject to the OpenConf License, available on    |
// | the OpenConf web site: www.OpenConf.com                              |
// +----------------------------------------------------------------------+

// List of questions to check for non-empty values when confirming whether a review is complete
// NOTE: A zero (0) will match as an empty value; PHP's empty() is used
$OC_completedReviewQuestionsAR = array('recommendation');

// Review questions
/*
	question: Full question
	short: Short question name for use in confirmation message and review display to chair/reviewers
	note: Note to accompany question
	type: Field type to use (radio, checkbox, text, textarea)
	usekey: TRUE - use values array key for checkbox/radio field value; FALSE - use array value or N/A (non-radio/checkbox)
	values: Array of radio/checkbox options or empty string if N/A
	delimiter: Delimiter to use to separate radio/checbox options (default: <br />)
	nobreak: TRUE - do not display divider line after question; FALSE - display line (default: FALSE)
*/
$OC_reviewQuestionsAR = array(
	'recommendation' => array(
		'question' => 'Recommendation:',
		'short' => 'Recommendation:',
		'note' => '',
		'type' => 'radio',
		'usekey' => TRUE,
		'values' => array(
			1 => 'Reject: <i>Content inappropriate to the conference or has little merit</i>',
			2 => 'Probable Reject: <i>Basic flaws in content or presentation or very poorly written</i>',
			3 => 'Marginal Tend to Reject: <i>Not as badly flawed; major effort necessary to make acceptable but content well-covered in literature already</i>',
			4 => 'Marginal Tend to Accept: <i>Content has merit, but accuracy, clarity, completeness, and/or writing should and could be improved in time</i>',
			5 => 'Clear Accept: <i>Content, presentation, and writing meet professional norms; improvements may be advisable but acceptable as is</i>',
			6 => 'Must Accept: <i>Candidate for outstanding submission. Suggested improvements still appropriate</i>'
		)
	),
	
	'category' => array(
		'question' => 'Submission Categorization:',
		'short' => 'Category:',
		'note' => '',
		'type' => 'radio',
		'usekey' => TRUE,
		'values' => array(
			1 => 'Highly theoretical',
			2 => 'Tends towards theoretical',
			3 => 'Balanced theory and practice',
			4 => 'Tends toward practical',
			5 => 'Highly practical'
		)
	),
	
	'value' => array(
		'question' => 'Overall Value Added to the Field:',
		'short' => 'Value Added:',
		'note' => 'Check as many as appropriate',
		'type' => 'checkbox',
		'usekey' => TRUE,
		'values' => array(
			1 => 'New information',
			2 => 'Valuable confirmation of present knowledge',
			3 => 'Clarity to present understanding',
			4 => 'New perspective, issue, or problem definition',
			5 => 'Not much',
			6 => 'Other'
		)
	),
	
	'familiar' => array(
		'question' => 'Reviewer Familiarity with Subject Matter:',
		'short' => 'Reviewer Familiarity:',
		'note' => 'Relates to the confidence you have in your review',
		'type' => 'radio',
		'usekey' => FALSE,
		'values' => array(
			'Low',
			'Moderate',
			'High'
		)
	),
	
	'bpcandidate' => array(
		'question' => 'Is this submission a candidate for the best submission award?',
		'short' => 'Best Sub. Candidate?',
		'note' => '',
		'type' => 'radio',
		'usekey' => FALSE,
		'values' => array(
			'Yes',
			'No',
			'Unsure'
		)
	),
	
	'length' => array(
		'question' => 'Is the submission length appropriate?',
		'short' => 'Appropriate Length:',
		'note' => '',
		'type' => 'radio',
		'usekey' => FALSE,
		'values' => array(
			'Yes',
			'No',
			'Unsure'
		)
	),
	
	'difference' => array(
		'question' => 'If from reading the submission you know who the author is, how different is this from earlier submissions on the same topic by the same author? That is, is it the same as or a slight modification of other submissions, with little or no new information?',
		'short' => 'Difference from Prior Work:',
		'note' => 'We use these suggestions in assigning submissions to sessions for the conference, but <u>not</u> in determining whether the submission is accepted)',
		'type' => 'radio',
		'usekey' => TRUE,
		'values' => array(
			1 => 'Totally or largely <u>different</u> from other submissions',
			2 => 'Moderately different from other submissions',
			3 => 'Totally or largely <u>identical</u> to other submissions',
			4 => 'Don\'t know'
		)
	),

	'sessions' => array(
		'question' => 'Optional: Which of the following session(s) would be the most appropriate for this submission?',
		'short' => 'Suggested Session(s):',
		'note' => 'We use these suggestions in assigning submissions to sessions for the conference, but not in determining whether the submission is accepted)',
		'type' => 'checkbox',
		'usekey' => TRUE,
		'values' => array()
	),
	
	'authorcomments' => array(
		'question' => 'Comments for the Authors',
		'short' => 'Comments to Author:',
		'note' => 'Constructive comments to the author(s) would be appreciated.',
		'type' => 'textarea',
		'usekey' => FALSE,
		'values' => ''
	),
	
	'pccomments' => array(
		'question' => 'Comments for the Program Committee (authors will not see these comments)',
		'short' => 'Comments to PC:',
		'note' => 'Reasons <u>must</u> be included for <u>all</u> submissions, because they help us determine what to do when reviewers disagree with each other.',
		'type' => 'textarea',
		'usekey' => FALSE,
		'values' => ''
	)
	
);

// Fill in session topics
$tq = "SELECT * FROM " . OCC_TABLE_TOPIC;
$tr = ocsql_query($tq) or err("Unable to retrieve topics");
while ($tt = mysql_fetch_assoc($tr)) {
	$OC_reviewQuestionsAR['sessions']['values'][$tt['topicid']] = useTopic($tt['short'], $tt['topicname'], 0);
}

if (oc_hookSet('committee-review-inc')) {
	foreach ($GLOBALS['OC_hooksAR']['committee-review-inc'] as $v) {
		require_once $v;
	}
}

?>
